==> haskell-process-extras-0.7.4-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.4
id: process-extras-0.7.4-HD89EKm3ia3DWX8cMnnb42
key: process-extras-0.7.4-HD89EKm3ia3DWX8cMnnb42
license: MIT
maintainer: David Fox <dsf@seereason.com>
author: David Lazar, Bas van Dijk, David Fox
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
abi: 5588df6e9ced6e08f328c858c791df24
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/process-extras-0.7.4
hs-libraries: HSprocess-extras-0.7.4-HD89EKm3ia3DWX8cMnnb42
depends:
    base-4.11.1.0 data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
    ListLike-4.6-3Z547COdop48WLCEwLJgjm mtl-2.2.2 process-1.6.3.0
    bytestring-0.10.8.2 text-1.2.3.0 deepseq-1.4.3.0
    generic-deriving-1.12.2-FRlrWco4nlsJ78sw56KYSH
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             ListLike-4.6-3Z547COdop48WLCEwLJgjm=1f970578cc30e74eda945bf514ab86d8
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             generic-deriving-1.12.2-FRlrWco4nlsJ78sw56KYSH=ae2b40e1455c1d6d7f74f3f88e89af93
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.4-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.4
id: process-extras-0.7.4-6h7QoB41FChD57wDnQDYy4
key: process-extras-0.7.4-6h7QoB41FChD57wDnQDYy4
license: MIT
maintainer: David Fox <dsf@seereason.com>
author: David Lazar, Bas van Dijk, David Fox
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
abi: 36f0a8c56879c5079a7bbc0e57868ab9
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/process-extras-0.7.4
hs-libraries: HSprocess-extras-0.7.4-6h7QoB41FChD57wDnQDYy4
depends:
    base-4.11.1.0 data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
    ListLike-4.6-3Z547COdop48WLCEwLJgjm mtl-2.2.2 process-1.6.3.0
    bytestring-0.10.8.2 text-1.2.3.0 deepseq-1.4.3.0
    generic-deriving-1.12.2-7Oz3MOVJ8xs5CvZfm34ik1
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             ListLike-4.6-3Z547COdop48WLCEwLJgjm=1f970578cc30e74eda945bf514ab86d8
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             generic-deriving-1.12.2-7Oz3MOVJ8xs5CvZfm34ik1=630716159475a76d5f5f79eb0a5a90ee
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
